==> nextcloud-25.0.8.tgz: nextcloud/apps/workflowengine/l10n/tr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Belirtilen işlem geçersiz",
    "The given regular expression is invalid" : "Belirtilen kurallı ifade geçersiz",
    "The given file size is invalid" : "Belirtilen dosya boyutu geçersiz",
    "The given tag id is invalid" : "Belirtilen etiket kodu geçersiz",
    "The given IP range is invalid" : "Belirtilen IP adresi aralığı geçersiz",
    "The given IP range is not valid for IPv4" : "Belirtilen IP adresi aralığı IPv4 için geçersiz",
    "The given IP range is not valid for IPv6" : "Belirtilen IP adresi aralığı IPv6 için geçersiz",
    "The given time span is invalid" : "Belirtilen zaman aralığı geçersiz",
    "The given start time is invalid" : "Belirtilen başlangıç zamanı geçersiz",
    "The given end time is invalid" : "Belirtilen bitiş zamanı geçersiz",
    "The given group does not exist" : "Belirtilen grup bulunamadı",
    "File" : "Dosya",
    "File created" : "Dosya oluşturuldu",
    "File updated" : "Dosya güncellendi",
    "File renamed" : "Dosya yeniden adlandırıldı",
    "File deleted" : "Dosya silindi",
    "File accessed" : "Dosyaya erişildi",
    "File copied" : "Dosya kopyalandı",
    "Tag assigned" : "Etiket atandı",
    "Someone" : "Biri",
    "%s created %s" : "%s oluşturuldu%s",
    "%s modified %s" : "%s değiştirildi%s",
    "%s deleted %s" : "%s silindi%s",
    "%s accessed %s" : "%s erişildi %s",
    "%s renamed %s" : "%s yeniden adlandırıldı%s",
    "%s copied %s" : "%s kopyalandı%s",
    "%s assigned %s to %s" : "%s atandı %s => %s",
    "Operation #%s does not exist" : "#%s işlemi bulunamadı",
    "Entity %s does not exist" : "%s varlığı bulunamadı",
    "Entity %s is invalid" : "%s varlığı geçersiz",
    "No events are chosen." : "Herhangi bir etkinlik seçilmemiş.",
    "Entity %s has no event %s" : "%s varlığının herhangi bir etkinliği yok %s",
    "Operation %s does not exist" : "%s işlemi bulunamadı",
    "Operation %s is invalid" : "%s işlemi geçersiz",
    "At least one check needs to be provided" : "En az bir denetim belirtilmelidir",
    "The provided operation data is too long" : "Belirtilen işlem verileri çok uzun",
    "Invalid check provided" : "Geçersiz denetim belirtildi",
    "Check %s does not exist" : "%s denetimi bulunamadı",
    "Check %s is invalid" : "%s denetimi geçersiz",
    "Check %s is not allowed with this entity" : "Bu varlık için %s denetimi yapılamaz",
    "The provided check value is too long" : "Belirtilen denetleme değeri çok uzun",
    "Check #%s does not exist" : "#%s denetimi bulunamadı",
    "Check %s is invalid or does not exist" : "%s denetimi geçersiz ya da bulunamadı",
    "Flow" : "Akış",
    "Nextcloud workflow engine" : "Nextcloud iş akışı işleyici",
    "Select a filter" : "Bir süzgeç seçin",
    "Select a comparator" : "Bir karşılaştırıcı seçin",
    "Remove filter" : "Süzgeci kaldır",
    "Select a file type" : "Bir dosya türü seçin",
    "e.g. httpd/unix-directory" : "örnek httpd/unix-directory",
    "Folder" : "Klasör",
    "Images" : "Görseller",
    "Office documents" : "Office belgeleri",
    "PDF documents" : "PDF belgeleri",
    "Custom MIME type" : "Özel MIME türü",
    "Custom mimetype" : "Özel MIME türü",
    "Please enter a valid time span" : "Lütfen geçerli bir tarih aralığı seçin",
    "Select a request URL" : "Bir istek adresi seçin",
    "Files WebDAV" : "Dosya WebDAV",
    "Custom URL" : "Özel adres",
    "Select a user agent" : "Bir kullanıcı uygulaması seçin",
    "Android client" : "Android istemcisi",
    "iOS client" : "iOS istemcisi",
    "Desktop client" : "Masaüstü istemcisi",
    "Thunderbird & Outlook addons" : "Thunderbird ve Outlook eklentileri",
    "Custom user agent" : "Özel kullanıcı uygulaması",
    "At least one event must be selected" : "En az bir etkinlik seçilmelidir",
    "Add new flow" : "Akış ekle",
    "When" : "Şu zamanda",
    "and" : "ve",
    "Add a new filter" : "Yeni süzgeç ekle",
    "Cancel" : "İptal",
    "Delete" : "Sil",
    "The configuration is invalid" : "Yapılandırma geçersiz",
    "Active" : "Etkin",
    "Save" : "Kaydet",
    "Available flows" : "Kullanılabilecek akışlar",
    "For details on how to write your own flow, check out the development documentation." : "Kendi akışınızı nasıl yazacağınızı öğrenmek için geliştirme belgelerine bakabilirsiniz.",
    "More flows" : "Diğer akışlar",
    "Browse the App Store" : "Uygulama mağazasına göz atın",
    "Show less" : "Daha az ayrıntı",
    "Show more" : "Daha çok ayrıntı",
    "Configured flows" : "Yapılandırılmış akışlar",
    "Your flows" : "Akışlarınız",
    "matches" : "şuna uyan",
    "does not match" : "şuna uymayan",
    "is" : "şu olan",
    "is not" : "şu olmayan",
    "File name" : "Dosya adı",
    "File MIME type" : "Dosya MIME türü",
    "File size (upload)" : "Dosya boyutu (yükleme)",
    "less" : "şundan küçük",
    "less or equals" : "şundan küçük ya da eşit",
    "greater or equals" : "şundan büyük ya da eşit",
    "greater" : "şundan büyük",
    "Request remote address" : "Uzak adres isteği",
    "matches IPv4" : "şu IPv4 adresine uyan",
    "does not match IPv4" : "şu IPv4 adresine uymayan",
    "matches IPv6" : "şu IPv6 adresine uyan",
    "does not match IPv6" : "şu IPv6 adresine uymayan",
    "File system tag" : "Dosya sistemi etiketi",
    "is tagged with" : "şununla etiketlenmiş",
    "is not tagged with" : "şununla etiketlenmemiş",
    "Request URL" : "İstek adresi",
    "Request time" : "İstek zamanı",
    "between" : "şunların arasında olan",
    "not between" : "şunların arasında olmayan",
    "Request user agent" : "Kullanıcı uygulaması istensin",
    "User group membership" : "Kullanıcı grubu üyeliği",
    "is member of" : "şunun üyesi olan",
    "is not member of" : "şunun üyesi olmayan",
    "Predefined URLs" : "Hazır adresler",
    "Others" : "Diğerleri"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/workflowengine/l10n/tr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Belirtilen işlem geçersiz",
    "The given regular expression is invalid" : "Belirtilen kurallı ifade geçersiz",
    "The given file size is invalid" : "Belirtilen dosya boyutu geçersiz",
    "The given tag id is invalid" : "Belirtilen etiket kodu geçersiz",
    "The given IP range is invalid" : "Belirtilen IP adresi aralığı geçersiz",
    "The given IP range is not valid for IPv4" : "Belirtilen IP adresi aralığı IPv4 için geçersiz",
    "The given IP range is not valid for IPv6" : "Belirtilen IP adresi aralığı IPv6 için geçersiz",
    "The given time span is invalid" : "Belirtilen zaman aralığı geçersiz",
    "The given start time is invalid" : "Belirtilen başlangıç zamanı geçersiz",
    "The given end time is invalid" : "Belirtilen bitiş zamanı geçersiz",
    "The given group does not exist" : "Belirtilen grup bulunamadı",
    "File" : "Dosya",
    "File created" : "Dosya oluşturuldu",
    "File updated" : "Dosya güncellendi",
    "File renamed" : "Dosya yeniden adlandırıldı",
    "File deleted" : "Dosya silindi",
    "File accessed" : "Dosyaya erişildi",
    "File copied" : "Dosya kopyalandı",
    "Tag assigned" : "Etiket atandı",
    "Someone" : "Biri",
    "%s created %s" : "%s oluşturuldu%s",
    "%s modified %s" : "%s değiştirildi%s",
    "%s deleted %s" : "%s silindi%s",
    "%s accessed %s" : "%s erişildi %s",
    "%s renamed %s" : "%s yeniden adlandırıldı%s",
    "%s copied %s" : "%s kopyalandı%s",
    "%s assigned %s to %s" : "%s atandı %s => %s",
    "Operation #%s does not exist" : "#%s işlemi bulunamadı",
    "Entity %s does not exist" : "%s varlığı bulunamadı",
    "Entity %s is invalid" : "%s varlığı geçersiz",
    "No events are chosen." : "Herhangi bir etkinlik seçilmemiş.",
    "Entity %s has no event %s" : "%s varlığının herhangi bir etkinliği yok %s",
    "Operation %s does not exist" : "%s işlemi bulunamadı",
    "Operation %s is invalid" : "%s işlemi geçersiz",
    "At least one check needs to be provided" : "En az bir denetim belirtilmelidir",
    "The provided operation data is too long" : "Belirtilen işlem verileri çok uzun",
    "Invalid check provided" : "Geçersiz denetim belirtildi",
    "Check %s does not exist" : "%s denetimi bulunamadı",
    "Check %s is invalid" : "%s denetimi geçersiz",
    "Check %s is not allowed with this entity" : "Bu varlık için %s denetimi yapılamaz",
    "The provided check value is too long" : "Belirtilen denetleme değeri çok uzun",
    "Check #%s does not exist" : "#%s denetimi bulunamadı",
    "Check %s is invalid or does not exist" : "%s denetimi geçersiz ya da bulunamadı",
    "Flow" : "Akış",
    "Nextcloud workflow engine" : "Nextcloud iş akışı işleyici",
    "Select a filter" : "Bir süzgeç seçin",
    "Select a comparator" : "Bir karşılaştırıcı seçin",
    "Remove filter" : "Süzgeci kaldır",
    "Select a file type" : "Bir dosya türü seçin",
    "e.g. httpd/unix-directory" : "örnek httpd/unix-directory",
    "Folder" : "Klasör",
    "Images" : "Görseller",
    "Office documents" : "Office belgeleri",
    "PDF documents" : "PDF belgeleri",
    "Custom MIME type" : "Özel MIME türü",
    "Custom mimetype" : "Özel MIME türü",
    "Please enter a valid time span" : "Lütfen geçerli bir tarih aralığı seçin",
    "Select a request URL" : "Bir istek adresi seçin",
    "Files WebDAV" : "Dosya WebDAV",
    "Custom URL" : "Özel adres",
    "Select a user agent" : "Bir kullanıcı uygulaması seçin",
    "Android client" : "Android istemcisi",
    "iOS client" : "iOS istemcisi",
    "Desktop client" : "Masaüstü istemcisi",
    "Thunderbird & Outlook addons" : "Thunderbird ve Outlook eklentileri",
    "Custom user agent" : "Özel kullanıcı uygulaması",
    "Select a trigger" : "Bir tetikleyici seçin",
    "At least one event must be selected" : "En az bir etkinlik seçilmelidir",
    "Add new flow" : "Akış ekle",
    "When" : "Şu zamanda",
    "and" : "ve",
    "Add a new filter" : "Yeni süzgeç ekle",
    "Cancel" : "İptal",
    "Delete" : "Sil",
    "The configuration is invalid" : "Yapılandırma geçersiz",
    "Active" : "Etkin",
    "Save" : "Kaydet",
    "Available flows" : "Kullanılabilecek akışlar",
    "For details on how to write your own flow, check out the development documentation." : "Kendi akışınızı nasıl yazacağınızı öğrenmek için geliştirme belgelerine bakabilirsiniz.",
    "No flows installed" : "Herhangi bir akış kurulmamış",
    "Ask your administrator to install new flows." : "Yöneticinizden yeni akışlar kurmasını isteyin.",
    "More flows" : "Diğer akışlar",
    "Browse the App Store" : "Uygulama mağazasına göz atın",
    "Show less" : "Daha az ayrıntı",
    "Show more" : "Daha çok ayrıntı",
    "Configured flows" : "Yapılandırılmış akışlar",
    "Your flows" : "Akışlarınız",
    "No flows configured" : "Herhangi bir akış yapılandırılmamış",
    "matches" : "şuna uyan",
    "does not match" : "şuna uymayan",
    "is" : "şu olan",
    "is not" : "şu olmayan",
    "File name" : "Dosya adı",
    "File MIME type" : "Dosya MIME türü",
    "File size (upload)" : "Dosya boyutu (yükleme)",
    "less" : "şundan küçük",
    "less or equals" : "şundan küçük ya da eşit",
    "greater or equals" : "şundan büyük ya da eşit",
    "greater" : "şundan büyük",
    "Request remote address" : "Uzak adres isteği",
    "matches IPv4" : "şu IPv4 adresine uyan",
    "does not match IPv4" : "şu IPv4 adresine uymayan",
    "matches IPv6" : "şu IPv6 adresine uyan",
    "does not match IPv6" : "şu IPv6 adresine uymayan",
    "File system tag" : "Dosya sistemi etiketi",
    "is tagged with" : "şununla etiketlenmiş",
    "is not tagged with" : "şununla etiketlenmemiş",
    "Request URL" : "İstek adresi",
    "Request time" : "İstek zamanı",
    "between" : "şunların arasında olan",
    "not between" : "şunların arasında olmayan",
    "Request user agent" : "Kullanıcı uygulaması istensin",
    "User group membership" : "Kullanıcı grubu üyeliği",
    "is member of" : "şunun üyesi olan",
    "is not member of" : "şunun üyesi olmayan",
    "Predefined URLs" : "Hazır adresler",
    "Others" : "Diğerleri"
},
"nplurals=2; plural=(n > 1);");
